.progress-info {
    margin-right: 15px;
    margin-top: 7px;
    font-size: 12px;
    font-weight: 400;
    color: #303030;
}

.sq-build-progress.progress {
    height: 12px;
    width: 221px;
    margin-top: 9px;
    float: left;
    margin-right: 23px;
    margin-bottom: 0;
    background-color: #ffffff;
    border: 1px solid #c5c5ce;
    border-radius: 6px;
    box-shadow: inset 0px 3px 6px -3px rgba(0, 0, 0, 0.30);
    border-radius: 0;
}

body .btn.sq-btn-process {
    float: left;
    margin-left: 8px;
}

.project-control-panel {
    position: absolute;
    top: 18px;
    right: 14px;
    z-index: 10;
}

.project-control-panel .btn {
    line-height: 26px;
}

.project-control-panel .btn.btn-default {
    border: 1px solid #c7c7cd;
}

.project-control-panel .btn i {
    font-size: 16px;
    vertical-align: -2px;
    margin-right: 7px;
}

.project-control-panel .btn.sq-btn-stop i {
    color: #ff0000;
}

.project-control-panel .btn.sq-btn-pause i {
    color: #f3683b;
}

.project-control-panel .btn.btn-default:disabled i {
    color: #a5a5a5;
}

.project-control-panel .btn:disabled {
    opacity: 1;
}

.project-control-panel .btn.btn-default:disabled {
    color: #6f6e6e;
}    

.project-control-panel .btn.btn.btn-primary {
    /*background: #00c825;
    border-bottom: 2px solid #00b421;
    border: 1px solid #bddefb;*/
    background: #00c825;
    background: -moz-linear-gradient(top, #00c825 0%, #00b421 100%);
    background: -webkit-linear-gradient(top, #00c825 0%,#00b421 100%);
    background: linear-gradient(to bottom, #00c825 0%,#00b421 100%);
    filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#00c825', endColorstr='#00b421',GradientType=0 );
    margin-top: 0;
}

.project-control-panel .btn.btn.btn-primary:hover {
    background: #00b421;
}

.project-control-panel .btn.btn.btn-primary:disabled {
    filter: none;
    background: #a7a7a7;
}