angular.module('app').directive('projectControlPanel', function () {
    return {
        restrict: 'AE',
        templateUrl: '../app/directives/projectControlPanel/projectControlPanel.html',
        scope: {
            onFinishLoading: '&',
            projectName: '@',
            fixedProject: '=',
            hideButtons: "@",
            instance: '=',
            disabled: '=',   
        },
        controller: 'ProjectControlPanelCtrl',
    }
});